@@ -7,11 +7,10 @@ struct pzk_pipe_dispatcher {
     int fd[2];
     int (*read_pipe)  (struct pzk_pipe_dispatcher*);
     int (*write_pipe) (struct pzk_pipe_dispatcher*);
+    void (*destroy)   (struct pzk_pipe_dispatcher*);
 };
 typedef struct pzk_pipe_dispatcher pzk_pipe_dispatcher_t;
 
-pzk_pipe_dispatcher_t* new_pzk_pipe_dispatcher(pzk_dequeue_t*);
-
-void destroy_pzk_pipe_dispatcher(pzk_pipe_dispatcher_t*);
+pzk_pipe_dispatcher_t* new_pzk_pipe_dispatcher(pzk_channel_t*);
 
 #endif // ifndef PZK_PIPE_DISPATCHER_H_
